{{- define "elasticsearch.curator" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "elasticsearchCurator" | include "stacklight.logLevel" -}}
{{- $retentionUnit := "days" }}
{{- $retentionUnitCount := .Values.elasticsearch.logstashRetentionTime }}
{{- if kindIs "string" .Values.elasticsearch.logstashRetentionTime }}
{{- if or (hasSuffix "y" .Values.elasticsearch.logstashRetentionTime) (hasSuffix "Y" .Values.elasticsearch.logstashRetentionTime) }}
  {{- $retentionUnit = "years" }}
  {{- $retentionUnitCount = trimSuffix "Y" (trimSuffix "y" .Values.elasticsearch.logstashRetentionTime) }}
{{- else if hasSuffix "M" .Values.elasticsearch.logstashRetentionTime }}
  {{- $retentionUnit = "months" }}
  {{- $retentionUnitCount = trimSuffix "M" .Values.elasticsearch.logstashRetentionTime }}
{{- else if or (hasSuffix "w" .Values.elasticsearch.logstashRetentionTime) (hasSuffix "W" .Values.elasticsearch.logstashRetentionTime) }}
  {{- $retentionUnit = "weeks" }}
  {{- $retentionUnitCount = trimSuffix "W" (trimSuffix "w" .Values.elasticsearch.logstashRetentionTime) }}
{{- else if or (hasSuffix "d" .Values.elasticsearch.logstashRetentionTime) (hasSuffix "D" .Values.elasticsearch.logstashRetentionTime) }}
  {{- $retentionUnit = "days" }}
  {{- $retentionUnitCount = trimSuffix "D" (trimSuffix "d" .Values.elasticsearch.logstashRetentionTime) }}
{{- else if or (hasSuffix "h" .Values.elasticsearch.logstashRetentionTime) (hasSuffix "H" .Values.elasticsearch.logstashRetentionTime) }}
  {{- $retentionUnit = "hours" }}
  {{- $retentionUnitCount = trimSuffix "H" (trimSuffix "h" .Values.elasticsearch.logstashRetentionTime) }}
{{- end }}
{{- end }}
{{- $esReplicas := 1 }}
{{- if .Values.highAvailabilityEnabled }}
  {{- $esReplicas = 3 }}
{{- end }}
cronjob:
  schedule: "{{ .Values.elasticsearch.cronJobSchedule }}"
configMaps:
  config_yml: |-
    ---
    client:
      hosts:
      - elasticsearch-master
      port: 9200
{{- if $logLevel }}
    logging:
      loglevel: {{ $logLevel | quote }}
{{- end }}
  action_file_yml: |-
    ---
    actions:
      1:
        action: open
        description: "Open closed indices for later evaluation"
        filters: []
        options:
          continue_if_exception: true
          disable_action: false
          ignore_empty_list: true
      2:
        action: delete_indices
        description: "Delete log indices older than {{ $retentionUnitCount }} {{ $retentionUnit }} (based on index creation date)."
        filters:
        - filtertype: pattern
          kind: regex
          value: '^(audit|kubernetes_events|logstash|notification)-'
        - filtertype: age
          direction: older
          source: creation_date
          unit: {{ $retentionUnit | quote }}
          unit_count: {{ $retentionUnitCount }}
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
{{- if .Values.elasticsearch.rotateOldDataOnStorageWatermark }}
      3:
        action: delete_indices
        description: "Delete indices to free storage space up to 75% (rounded up) of cluster total capacity in attempt to satisfy Elasticsearch's storage low watermark (default: 85%)"
        filters:
        - filtertype: pattern
          kind: regex
          value: '^\.'
          exclude: true
        - filtertype: space
          disk_space: {{ div (mul 5 (mul $esReplicas (trimSuffix "G" (trimSuffix "Gi" .Values.elasticsearch.persistentVolumeClaimSize)))) 20 }}
          use_age: true
          source: creation_date
          reverse: true
        options:
          continue_if_exception: false
          disable_action: false
          ignore_empty_list: true
{{- end }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "curator") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "elasticsearchCurator") }}
{{- end }}
