{{- define "grafana" -}}
{{/* https://grafana.com/docs/grafana/latest/administration/configuration/#level */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "critical") "component" "grafana" | include "stacklight.logLevel" -}}
adminPassword: admin
sidecar_datasources:
  prometheus:
    type: prometheus
    url: http://prometheus-relay
    isDefault: true
podAnnotations:
  prometheus.io/port: "3000"
  prometheus.io/scrape: "true"
{{- if .Values.mke.enabled }}
rbac:
  pspUseAppArmor: false
{{- end }}
dashboards:
  default:
    alertmanager:
      file: dashboards/alertmanager.json
  {{- if .Values.calico.enabled }}
    calico:
      file: dashboards/calico.json
  {{- end }}
  {{- if .Values.ceph.enabled }}
    ceph-cluster:
      file: dashboards/ceph-cluster.json
    ceph-nodes:
      file: dashboards/ceph-nodes.json
    ceph-osds:
      file: dashboards/ceph-osds.json
    ceph-pools:
      file: dashboards/ceph-pools.json
  {{- end }}
  {{- if .Values.ironic.enabled }}
    ironic:
      file: dashboards/ironic.json
  {{- end }}
  {{- if .Values.logging.enabled }}
    elasticsearch:
      file: dashboards/elasticsearch.json
  {{- end }}
    grafana:
      file: dashboards/grafana.json
    kubernetes-cluster:
      file: dashboards/kubernetes-cluster.json
    kubernetes-deployment:
      file: dashboards/kubernetes-deployment.json
    kubernetes-namespace:
      file: dashboards/kubernetes-namespace.json
    kubernetes-node:
      file: dashboards/kubernetes-node.json
    kubernetes-pod:
      file: dashboards/kubernetes-pod.json
  {{- if .Values.nginxExporter.enabled }}
    nginx:
      file: dashboards/nginx.json
  {{- end }}
    node-exporter:
      file: dashboards/node-exporter.json
    postgresql:
      file: dashboards/postgresql.json
    prometheus:
      file: dashboards/prometheus.json
    pushgateway:
      file: dashboards/pushgateway.json
    relay:
      file: dashboards/relay.json
  {{- if .Values.openstack.enabled }}
    memcached:
      file: dashboards/memcached.json
    mysql:
      file: dashboards/mysql.json
    cinder:
      file: dashboards/cinder.json
    glance:
      file: dashboards/glance.json
    {{- if .Values.openstack.gnocchi.enabled }}
    gnocchi:
      file: dashboards/gnocchi.json
    {{- end }}
    heat:
      file: dashboards/heat.json
    {{- if .Values.openstack.ironic.enabled }}
    ironic-openstack:
      file: dashboards/ironic-openstack.json
    {{- end }}
    keystone:
      file: dashboards/keystone.json
    {{- if and (not .Values.tungstenFabricMonitoring.enabled) (.Values.openstack.arpingCheck.enabled) }}
    kpi-downtime:
      file: dashboards/kpi-downtime.json
    {{- end }}
    {{- if .Values.logging.enabled }}
    kpi-provisioning:
      file: dashboards/kpi-provisioning.json
    {{- end }}
    neutron:
    {{- if .Values.tungstenFabricMonitoring.enabled }}
      file: dashboards/neutron-tf.json
    {{- else }}
      file: dashboards/neutron.json
    {{- end }}
    nova-az:
      file: dashboards/nova-az.json
    nova-hypervisor:
      file: dashboards/nova_hypervisor.json
    nova-overview:
      file: dashboards/nova_overview.json
    nova-top-instances:
      file: dashboards/nova-top-instances.json
    nova-top-tenants:
      file: dashboards/nova-top-tenants.json
    nova-top-users:
      file: dashboards/nova-top-users.json
    nova-utilization:
      file: dashboards/nova-utilization.json
    openstack-overview:
      file: dashboards/openstack_overview.json
    nginx-ingress-controller:
      file: dashboards/nginx-ingress-controller.json
  {{- end }}
  {{- if or .Values.openstack.enabled .Values.tungstenFabricMonitoring.enabled }}
    rabbitmq:
      file: dashboards/rabbitmq.json
  {{- end }}
  {{- if .Values.tungstenFabricMonitoring.enabled }}
    cassandra:
      file: dashboards/cassandra.json
    kafka:
      file: dashboards/kafka.json
    redis:
      file: dashboards/redis.json
    tf-controller:
      file: dashboards/tf-controller.json
    tf-vrouter:
      file: dashboards/tf-vrouter.json
    zookeeper:
      file: dashboards/zookeeper.json
  {{- end }}
  {{- if .Values.telemetry.telemeterServer.enabled }}
    telemeter-clusters-overview:
      file: dashboards/telemeter-clusters-overview.json
    telemeter-server:
      file: dashboards/telemeter-server.json
  {{- end }}
  {{- if .Values.mke.enabled }}
    mke-cluster:
      file: dashboards/mke-cluster.json
    mke-containers:
      file: dashboards/mke-containers.json
  {{- end }}
grafana.ini:
  dashboards:
    default_home_dashboard_path: /var/lib/grafana/dashboards/default/{{ .Values.grafana.homeDashboard }}.json
  auth:
    disable_login_form: {{ .Values.grafana.loginFormDisabled }}
  auth.anonymous:
    enabled: {{ .Values.grafana.anonymousAuthEnabled }}
    org_role: Admin
{{- if .Values.grafana.ldap.enabled }}
  auth.ldap:
    enabled: true
    allow_sign_up: true
    config_file: /etc/grafana/ldap.toml
{{- end }}
  database:
    type: postgres
    host: {{ include "stacklight.currentPatroni" . }}
    port: "5432"
    name: grafana
    user: grafana
    password: grafanadb
{{- if $logLevel }}
  log:
    level: {{ $logLevel | quote }}
{{- end }}
{{- if .Values.grafana.ldap.enabled }}
ldap:
  existingSecret: {{ .Values.grafana.ldap.existingSecret }}
  config: {{ .Values.grafana.ldap.config }}
{{- end }}

image:
  {{- include "stacklight.getImage" (dict "root" . "image" "grafana") | nindent 2 }}

renderer:
  enabled: {{ .Values.grafana.renderer.enabled }}
  image: {{ include "stacklight.getImage" (dict "root" . "image" "grafanaImageRenderer" "flat" true) | quote }}
  {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "grafanaRenderer") | indent 2 }}
curlImage:
  {{- include "stacklight.getImage" (dict "root" . "image" "curl") | nindent 2 }}
initChownData:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "busybox") | nindent 4 }}
sidecar:
  image: {{ include "stacklight.getImage" (dict "root" . "image" "k8sSidecar" "flat" true) | quote }}
waitForDb:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "pgbouncer") | nindent 4 }}
deploymentStrategy:
  type: RollingUpdate
  rollingUpdate:
    maxUnavailable: 1
{{- if .Values.exposeLoadBalancers }}
service:
  type: LoadBalancer
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "grafana") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "grafana") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "grafana") }}
{{- end }}
