{{- define "kibana" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "critical" "fatal") "component" "kibana" | include "stacklight.logLevel" -}}
elasticsearchHosts: "http://elasticsearch-master:9200"
files:
  kibana.yml:
{{- if $logLevel }}
    logging.root.level: {{ $logLevel | quote }}
{{- end }}
    kibana.defaultAppId: dashboard/2d53aa40-ad1f-11e9-9839-052bda0fdf49
    security.showInsecureClusterWarning: false
    xpack.apm.enabled: false
    xpack.apm.ui.enabled: false
    xpack.security.enabled: false
{{- if .Values.elasticsearch.kibanaExtraConfig }}
    {{ toYaml .Values.elasticsearch.kibanaExtraConfig | nindent 4 }}
{{- end }}
dashboardImport:
  enabled: true
  timeout: 600
  defaultIndexPattern: "logstash-index-pattern"
  xpackauth:
    enabled: false
    username: myuser
    password: mypass
  dashboards:
    logs: true
    kubernetes_events: true
    {{- if .Values.openstack.enabled }}
    notifications: true
    {{- end }}

{{- $resources := mergeOverwrite (index (index .Values.resourcesPerClusterSize "kibana" | default (dict .Values.clusterSize dict)) .Values.clusterSize) (index .Values.resources "kibana") }}
{{- if and (hasKey $resources "limits") (index (default (dict) $resources.limits) "memory") }}
{{- $maxMemory := $resources.limits.memory }}
{{- if hasSuffix "Gi" $maxMemory }}
  {{- $maxMemory = mul 1024 ($maxMemory | trimSuffix "Gi" | int64) }}
{{- else if hasSuffix "Mi" $maxMemory }}
  {{- $maxMemory = $maxMemory | trimSuffix "Mi" | int64 }}
{{- end }}
env:
  NODE_OPTIONS: "--max-http-header-size=262144 --max-old-space-size={{ sub $maxMemory 512 }}"
{{- end }}

image:
  {{- include "stacklight.getImage" (dict "root" . "image" "kibana") | nindent 2 }}

initContainers:
  es-check:
    image: {{ include "stacklight.getImage" (dict "root" . "image" "curl" "flat" true) | quote }}
{{- if .Values.exposeLoadBalancers }}
service:
  type: LoadBalancer
{{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "kibana") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "kibana") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "kibana") }}
{{- end }}
