{{- define "telegraf.common" -}}
image:
  {{- $image := include "stacklight.getImage" (dict "root" . "image" "telegraf") | fromYaml }}
  {{- $_ := set $image "repo" (index $image "repository") }}
  {{- pick $image "repo" "tag" | toYaml | nindent 2 }}
{{- end -}}

{{- define "telegraf.common.ds.override" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "info" "error" "error" "crit" "error") "component" "telegrafDs" | include "stacklight.logLevel" -}}
config:
  agent:
    debug: {{ eq "debug" $logLevel }}
    quiet: {{ eq "error" $logLevel }}
{{ include "stacklight.resources" (dict "inTplValues" .Values "service" "telegrafDs") }}
tolerations:
- effect: "NoSchedule"
  key: "node-role.kubernetes.io/master"
  operator: "Exists"
{{- if .Values.mke.enabled }}
- effect: "NoSchedule"
  key: "com.docker.ucp.manager"
  operator: "Exists"
{{- end }}
{{- $tolerations := (concat .Values.tolerations.default .Values.tolerations.component.telegrafDs) | uniq }}
{{- if $tolerations }}
  {{ toYaml $tolerations | nindent 0 }}
{{- end }}
{{- end -}}

{{- define "telegraf.common.ds" -}}
{{- $telegrafCommon := include "telegraf.common" . | fromYaml }}
{{- $telegrafCommonDsOverride := include "telegraf.common.ds.override" . | fromYaml }}
{{- merge $telegrafCommonDsOverride $telegrafCommon | toYaml }}
{{- end -}}

{{- define "telegraf.common.s.override" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "debug" "debug" "info" "info" "error" "error") "component" "telegrafS" | include "stacklight.logLevel" -}}
config:
  agent:
    debug: {{ eq "debug" $logLevel }}
    quiet: {{ eq "error" $logLevel }}
{{ include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "telegrafS") }}
{{ include "stacklight.resources" (dict "inTplValues" .Values "service" "telegrafS") }}
{{ include "stacklight.tolerations" (dict "inTplValues" .Values "service" "telegrafS") }}
{{- end -}}

{{- define "telegraf.common.s" -}}
{{- $telegrafCommon := include "telegraf.common" . | fromYaml }}
{{- $telegrafCommonSOverride := include "telegraf.common.s.override" . | fromYaml }}
{{- merge $telegrafCommonSOverride $telegrafCommon | toYaml }}
{{- end -}}

{{- define "telegrafOpenstack.override" -}}
config:
  inputs:
  - internal:
      interval: "{{ .Values.openstack.telegraf.interval }}"
  - openstack:
      cpu_ratio: {{ .Values.openstack.telegraf.cpuAllocationRatio }}
      domain: "{{ .Values.openstack.telegraf.credentialsConfig.domain }}"
      identity_endpoint: "{{ .Values.openstack.telegraf.credentialsConfig.identityEndpoint }}"
      insecure_skip_verify: {{ .Values.openstack.telegraf.insecure }}
      interval: "{{ .Values.openstack.telegraf.interval }}"
      password: "{{ .Values.openstack.telegraf.credentialsConfig.password }}"
      project: "{{ .Values.openstack.telegraf.credentialsConfig.project }}"
      region: "{{ .Values.openstack.telegraf.credentialsConfig.region }}"
  {{- if .Values.tungstenFabricMonitoring.enabled }}
      skip_networking_agents: true
  {{- end }}
      skip_public_endpoints: {{ .Values.openstack.telegraf.skipPublicEndpoints }}
      username: "{{ .Values.openstack.telegraf.credentialsConfig.username }}"
  outputs:
  - prometheus_client:
      expiration_interval: "{{ .Values.openstack.telegraf.interval }}{{ .Values.openstack.telegraf.interval }}"
      listen: ":9126"
fullnameOverride: "telegraf-openstack"
openstackCredentialsDiscovery:
  enabled: {{ .Values.openstack.telegraf.credentialsDiscovery.enabled }}
  image:
    {{- $image := include "stacklight.getImage" (dict "root" . "image" "curlJq") | fromYaml }}
    {{- $_ := set $image "repo" (index $image "repository") }}
    {{- pick $image "repo" "tag" | toYaml | nindent 4 }}
  namespace: {{ .Values.openstack.telegraf.credentialsDiscovery.namespace }}
  secretName: {{ .Values.openstack.telegraf.credentialsDiscovery.secretName }}
  {{- if .Values.openstack.telegraf.credentialsDiscovery.secretChecksum }}
  secretChecksum: {{ .Values.openstack.telegraf.credentialsDiscovery.secretChecksum }}
  {{- end }}
{{- end -}}

{{- define "telegrafOpenstack" -}}
{{- $telegrafCommonS := include "telegraf.common.s" . | fromYaml }}
{{- $telegrafOpenstackOverride := include "telegrafOpenstack.override" . | fromYaml }}
{{- merge $telegrafOpenstackOverride $telegrafCommonS | toYaml }}
{{- end -}}

{{- define "telegrafDsSmart.override" -}}
config:
  inputs:
  - smart:
      attributes: true
      interval: "30s"
      path: "/usr/sbin/smartctl"
  - internal:
      interval: "30s"
  processors:
  - enum:
      mapping:
        field: health_ok
        value_mappings:
          "false": 0
          "true": 1
  outputs:
  - prometheus_client:
      expiration_interval: "1m"
      listen: ":9126"
{{- end -}}

{{- define "telegrafDsSmart" -}}
{{- $telegrafCommonDs := include "telegraf.common.ds" . | fromYaml }}
{{- $telegrafDsSmartOverride := include "telegrafDsSmart.override" . | fromYaml }}
{{- merge $telegrafDsSmartOverride $telegrafCommonDs | toYaml }}
{{- end -}}

{{- define "telegrafDsArpingCheck.override" -}}
affinity:
  nodeAffinity:
    requiredDuringSchedulingIgnoredDuringExecution:
      nodeSelectorTerms:
      - matchExpressions:
        - key: openvswitch
          operator: In
          values:
          - enabled
        - key: openstack-gateway
          operator: In
          values:
          - enabled
      - matchExpressions:
        - key: openvswitch
          operator: In
          values:
          - enabled
        - key: openstack-control-plane
          operator: In
          values:
          - enabled
      - matchExpressions:
        - key: linuxbridge
          operator: In
          values:
          - enabled
        - key: openstack-gateway
          operator: In
          values:
          - enabled
      - matchExpressions:
        - key: linuxbridge
          operator: In
          values:
          - enabled
        - key: openstack-control-plane
          operator: In
          values:
          - enabled
config:
  inputs:
  - internal:
      interval: 30s
  - exec:
      commands: ["/opt/usr/local/bin/check_ovs_arping.py --host prometheus-server.stacklight.svc"]
      data_format: influx
      interval: 30s
      timeout: 20s
  outputs:
  - prometheus_client:
      expiration_interval: "1m"
      listen: ":9126"
{{- end -}}

{{- define "telegrafDsArpingCheck" -}}
{{- $telegrafCommonDs := include "telegraf.common.ds" . | fromYaml }}
{{- $telegrafDsArpingCheckOverride := include "telegrafDsArpingCheck.override" . | fromYaml }}
{{- merge $telegrafDsArpingCheckOverride $telegrafCommonDs | toYaml }}
{{- end -}}

{{- define "telegrafDockerSwarm.override" -}}
config:
  inputs:
  - docker:
      container_name_exclude: [ '*' ]
      docker_node_label_include: [ 'com.docker.ucp.orchestrator.*' ]
      endpoint:  "https://ucp-controller.kube-system.svc.cluster.local"
      gather_networks: true
      gather_nodes: true
      gather_services: true
      interval: "30s"
      perdevice:  true
      timeout: "10s"
      tls_ca:  "/tmp/ca.pem"
      tls_cert: "/tmp/cert.pem"
      tls_key: "/tmp/key.pem"
      total: false
  - internal:
      interval: "30s"
  outputs:
  - prometheus_client:
      expiration_interval: "1m"
      listen: ":9126"
extraVolumeMounts:
- name: mkecerts
  mountPath: /tmp
extraVolumes:
- name: mkecerts
  hostPath:
    path: "{{ .Values.mke.dockerdDataRoot }}/volumes/ucp-node-certs/_data"
fullnameOverride: "telegraf-docker-swarm"
{{- end -}}

{{- define "telegrafDockerSwarm" -}}
{{- $telegrafCommonS := include "telegraf.common.s" . | fromYaml }}
{{- $telegrafDockerSwarmOverride := include "telegrafDockerSwarm.override" . | fromYaml }}
{{- merge $telegrafDockerSwarmOverride $telegrafCommonS | toYaml }}
{{- end -}}
